@@ -171,7 +171,7 @@ class BoltArraySpark(BoltArray):
 
         return self._constructor(rdd, shape=shape, split=swapped.split).__finalize__(swapped)
 
-    def filter(self, func, axis=(0,)):
+    def filter(self, func, axis=(0,), sort=False):
         """
         Filter array along an axis.
 
@@ -188,17 +188,23 @@ class BoltArraySpark(BoltArray):
         axis : tuple or int, optional, default=(0,)
             Axis or multiple axes to filter along.
 
+        sort: bool, optional, default=False
+            Whether or not to sort by key before reindexing
+
         Returns
         -------
         BoltArraySpark
         """
         axis = tupleize(axis)
-        if len(axis) != 1:
-            raise NotImplementedError("Filtering over multiple axes will not be "
-                                      "supported until SparseBoltArray is implemented.")
 
         swapped = self._align(axis)
-        rdd = swapped._rdd.values().filter(func)
+        def f(record):
+            return func(record[1])
+        rdd = swapped._rdd.filter(f)
+        if sort:
+            rdd = rdd.sortByKey().values()
+        else:
+            rdd = rdd.values()
 
         # count the resulting array in order to reindex (linearize) the keys
         count, zipped = zip_with_index(rdd)
@@ -207,7 +213,7 @@ class BoltArraySpark(BoltArray):
         reindexed = zipped.map(lambda kv: (tupleize(kv[1]), kv[0]))
 
         # since we can only filter over one axis, the remaining shape is always the following
-        remaining = list(swapped.shape[1:])
+        remaining = list(swapped.shape[len(axis):])
         if count != 0:
             shape = tuple([count] + remaining)
         else:
